include "root" {
  path = find_in_parent_folders()
}

terraform {
  source = "${get_repo_root()}//modules/eks-addon-csi-ebs"
}

dependency "eks" {
  config_path = "../eks"

  mock_outputs_allowed_terraform_commands = ["validate", "plan"]
  mock_outputs = {
    cluster_id                         = "fake-cluster-id"
    cluster_endpoint                   = "https://fake-cluster-endpoint.eks.amazonaws.com"
    cluster_oidc_issuer_url            = "https://oidc.eks.us-east-2.amazonaws.com/id/FAKEIDENTIFIERXXXXXXXXXXXXXXXXXX"
    cluster_certificate_authority_data = "ZmFrZS1jYS1jZXJ0LWRhdGE="
    oidc_provider_arn                  = "arn:aws:iam::999999999999:role/FakeRoleName"
  }
}

dependencies {
  paths = ["../aws-load-balancer-controller"]
}

locals {
  config_vars = read_terragrunt_config(find_in_parent_folders("config.hcl"))

  addon_version = local.config_vars.locals.eks_addon_versions["aws-ebs-csi-driver"]
}

generate = local.config_vars.generate

inputs = {
  eks_cluster_id                         = dependency.eks.outputs.cluster_id
  eks_cluster_oidc_issuer_url            = dependency.eks.outputs.cluster_oidc_issuer_url
  eks_oidc_provider_arn                  = dependency.eks.outputs.oidc_provider_arn
  eks_cluster_endpoint                   = dependency.eks.outputs.cluster_endpoint
  eks_cluster_certificate_authority_data = dependency.eks.outputs.cluster_certificate_authority_data
  addon_version                          = local.addon_version
}
