include "root" {
  path = find_in_parent_folders()
}

terraform {
  source = "${get_repo_root()}//modules/eks-kube-prometheus-stack"
}

dependency "eks" {
  config_path = "../eks"

  # Configure mock outputs for the `validate` and `plan` commands that are returned when there are no outputs available
  # (e.g the module hasn't been applied yet)
  mock_outputs_allowed_terraform_commands = ["validate", "plan"]
  mock_outputs = {
    cluster_id                         = "fake-cluster-id"
    cluster_endpoint                   = "https://fake-cluster-endpoint.eks.amazonaws.com"
    cluster_certificate_authority_data = "ZmFrZS1jYS1jZXJ0LWRhdGE="
  }
}

dependency "private_dns" {
  config_path = "../dns-private"

  mock_outputs_allowed_terraform_commands = ["validate", "plan"]
  mock_outputs = {
    dns_zone = {
      name    = "fake.zone.com"
      zone_id = "ZXXXXXXXXXXXXXXXXXXX"
    }
  }
}

locals {
  config_vars = read_terragrunt_config(find_in_parent_folders("config.hcl"))
}

inputs = {
  cluster_id                         = dependency.eks.outputs.cluster_id
  cluster_endpoint                   = dependency.eks.outputs.cluster_endpoint
  cluster_certificate_authority_data = dependency.eks.outputs.cluster_certificate_authority_data
  domain                             = dependency.private_dns.outputs.dns_zone.name
}
